@@ -13,3 +13,16 @@ beta.binomial=function(alpha=1.0, beta=1.0) {
     structure(list(family="Beta-Binomial", hyper.parameters=c(alpha, beta)),
               class="prior")
  }
+
+
+tr.beta.binomial=function(alpha=1.0, beta=1.0, trunc) {
+    structure(list(family="Trunc-Beta-Binomial", hyper.parameters=c(alpha, beta, trunc)),
+              class="prior")
+ }
+
+
+
+tr.poisson=function(lambda, trunc) {
+    structure(list(family="Trunc-Poisson", hyper.parameters=c(lambda, trunc)),
+              class="prior")
+ }
