@@ -1,12 +1,9 @@
 #include "sampling.h"
 #include "family.h"
+#include "betapriorfamily.h"
 #include "bas-glm.h"
 
 
-double FitModel(SEXP Rcoef_m, SEXP Rse_m, double *XtY, double *XtX, int *model_m,
-			  double *XtYwork, double *XtXwork, double yty, double SSY, int pmodel, int p,
-			  int nobs, int m, double *pmse_m);
-
 
 int topk(Bit **models, double *prob, int k, struct Var *vars, int n, int p);
 void insert_children(int subset, double *list, double *subsetsum,
@@ -22,16 +19,18 @@ void print_subset(int subset, int rank, Bit **models, Bit *model,
 int withprob(double p);
 
 SEXP glm_deterministic(SEXP Y, SEXP X, SEXP Roffset, SEXP Rweights, 
-			  SEXP Rprobinit, SEXP Rmodeldim, SEXP modelprior, 
-			  SEXP Ra, SEXP Rb, SEXP Rs,
+		       SEXP Rprobinit, SEXP Rmodeldim, SEXP modelprior, SEXP betaprior,
 		       SEXP family, SEXP Rcontrol, SEXP Rlaplace) {
 	int nProtected = 0;
 	int nModels=LENGTH(Rmodeldim);
 
 	glmstptr * glmfamily;
-
 	glmfamily = make_glmfamily_structure(family);
 
+	betapriorptr *betapriorfamily;
+	betapriorfamily = make_betaprior_structure(betaprior, family);
+
+	
 	//  Rprintf("Allocating Space for %d Models\n", nModels) ;
 	SEXP ANS = PROTECT(allocVector(VECSXP, 14)); ++nProtected;
 	SEXP ANS_names = PROTECT(allocVector(STRSXP, 14)); ++nProtected;
@@ -78,7 +77,9 @@ SEXP glm_deterministic(SEXP Y, SEXP X, SEXP Roffset, SEXP Rweights,
 		SEXP Rmodel_m =	PROTECT(allocVector(INTSXP,pmodel));
 		GetModel_m(Rmodel_m, model, p);
 		//evaluate logmargy and shrinkage
-		SEXP glm_fit = PROTECT(glm_FitModel(X, Y, Rmodel_m, Roffset, Rweights, glmfamily, Rcontrol, Ra, Rb, Rs, Rlaplace));	
+		SEXP glm_fit = PROTECT(glm_FitModel(X, Y, Rmodel_m, Roffset, Rweights,
+						    glmfamily, Rcontrol, Rlaplace,
+						    betapriorfamily));	
 		double prior_m  = compute_prior_probs(model,pmodel,p, modelprior);
 		logmargy = REAL(getListElement(getListElement(glm_fit, "lpy"),"lpY"))[0];
 		shrinkage_m = REAL(getListElement(getListElement(glm_fit, "lpy"),	
@@ -116,10 +117,10 @@ SEXP glm_deterministic(SEXP Y, SEXP X, SEXP Roffset, SEXP Rweights,
 	SET_STRING_ELT(ANS_names, 6, mkChar("deviance"));
 
 	SET_VECTOR_ELT(ANS, 7, beta);
-	SET_STRING_ELT(ANS_names, 7, mkChar("coefficients"));
+	SET_STRING_ELT(ANS_names, 7, mkChar("mle"));
 
 	SET_VECTOR_ELT(ANS, 8, se);
-	SET_STRING_ELT(ANS_names, 8, mkChar("se"));
+	SET_STRING_ELT(ANS_names, 8, mkChar("mle.se"));
 
 	SET_VECTOR_ELT(ANS, 9, shrinkage);
 	SET_STRING_ELT(ANS_names, 9, mkChar("shrinkage"));
