@@ -89,23 +89,24 @@ SEXP gglm_lpy(SEXP RX, SEXP RY, SEXP Rcoef, SEXP Rmu, glmstptr * glmfamily, beta
 	SEXP Rshrinkage=PROTECT(allocVector(REALSXP,1)); ++nProtected; 
 	double shrinkage_m = 1.0;
 
-	double loglik_mle = 0.0;
+	double loglik_mle = 0.0, temp = 0.0;
 	double sum_Ieta = 0.0, logdet_Iintercept;
+	int i, j,l, base;
 	
 
 	loglik_mle = glmfamily->loglik(Y, mu, n);
 	glmfamily->info_matrix(Y, mu, Ieta, n);
 
 	for (int i = 0; i < n; i++) {
-		sum_Ieta += Ieta[i];
+	        sum_Ieta += Ieta[i];
 	}
 
 	logdet_Iintercept = log(sum_Ieta);
 	
 
 	for (int i = 0; i < p; i++) {
-	 double temp = 0.0;
-	 int base = i * n;
+	  double temp = 0.0;
+	  int base = i * n;
 	 for (int j = 0; j < n; j++) {
 	   temp += X[base + j] * Ieta[j];
 	 }
@@ -114,14 +115,14 @@ SEXP gglm_lpy(SEXP RX, SEXP RY, SEXP Rcoef, SEXP Rmu, glmstptr * glmfamily, beta
        
        //Xc <- X - rep(1,n) %*% t((t(X) %*% Ieta)) / sum.Ieta;
 	for (int i =0, l =0; i < p; i++) {
-	 double temp = XIeta[i];
+	   double temp = XIeta[i];
 	 for (int j = 0; j < n; j++,l++) {
 	   Xc[l] = X[l] - temp;
 	 }
        }
 
        //Q <- sum((Xc %*% beta)^2 * Ieta);
-       for (int j = 0; j < n; j++) { //double check if this is already zero by default	
+       for (int j = 0; j < n; j++) { //double check if this is already zero by default
 	 XcBeta[j] = 0.0;
        }
        
@@ -131,7 +132,7 @@ SEXP gglm_lpy(SEXP RX, SEXP RY, SEXP Rcoef, SEXP Rmu, glmstptr * glmfamily, beta
 	   XcBeta[j] += Xc[l] * beta;
 	 }
        }
-       
+
        Q = 0.0;
        for (int j = 0; j < n; j++) { 
 	 Q += XcBeta[j] * XcBeta[j] * Ieta[j];
@@ -144,8 +145,8 @@ SEXP gglm_lpy(SEXP RX, SEXP RY, SEXP Rcoef, SEXP Rmu, glmstptr * glmfamily, beta
      shrinkage_m = betapriorfamily->shrinkage_fun(betapriorfamily->hyperparams, p, Q, laplace);
 
      intercept = coef[0];
-     for ( int i = 1; i < p; i++) {
-       intercept += XIeta[i]*coef[i]*(1.0 - shrinkage_m);
+     for ( int i = 0; i < p; i++) {
+       intercept += XIeta[i]*coef[i+1]*(1.0 - shrinkage_m);
      }
      REAL(Rintercept)[0] = intercept;
      REAL(RlpY)[0] = lpY;
