@@ -22,7 +22,9 @@ void compute_modelprobs(SEXP Rmodelprobs,  SEXP Rlogmarg, SEXP Rpriorprobs, int
 	}	
 
 	for (m = 0; m < k; m++) {
-		modelprobs[m] = exp(modelprobs[m] + log(priorprobs[m]) - log(nc));
+	  /*		modelprobs[m] = exp(modelprobs[m] +
+			log(priorprobs[m]) - log(nc)); */
+		modelprobs[m] = exp(modelprobs[m] - log(nc))*priorprobs[m];
 	}	
 }
 
@@ -69,6 +71,10 @@ double compute_prior_probs(int *model, int modeldim, int p, SEXP modelprior) {
 
   if  (strcmp(family, "Beta-Binomial") == 0) 
     priorprob = beta_binomial(modeldim, p, hyper_parameters);
+  if  (strcmp(family, "Trunc-Beta-Binomial") == 0) 
+    priorprob = trunc_beta_binomial(modeldim, p, hyper_parameters);
+  if  (strcmp(family, "Trunc-Poisson") == 0) 
+    priorprob = trunc_poisson(modeldim, p, hyper_parameters);
   if (strcmp(family, "Bernoulli") == 0) 
     priorprob = Bernoulli(model, p, hyper_parameters);
   return(priorprob);
@@ -101,3 +107,30 @@ double beta_binomial(int modeldim, int p, double *hyper) {
 	     lbeta(hyper[0], hyper[1])));
 }
 
+double trunc_beta_binomial(int modeldim, int p, double *hyper) {
+  /* modeldim and p include the intercept so subtact 1 from each */
+
+  double prior;
+  if ((double) (modeldim -1) <= hyper[2]) {
+      prior = exp(lbeta((double) modeldim - 1.0 + hyper[0], (double) (p - modeldim) + hyper[1]) - 
+		  lbeta(hyper[0], hyper[1]));
+      //      Rprintf("pass \n");
+      
+    }
+  else {prior = 0.0;}
+
+  /*  Rprintf("prior %lf pmodel= %d s0 = %lf\n", prior, modeldim,
+      hyper[2]); */
+  return(prior);
+}
+
+double trunc_poisson(int modeldim, int p, double *hyper) {
+  /* modeldim and p include the intercept so subtact 1 from each */
+
+  double prior = 0.0;
+  if ((double) (modeldim -1) <= hyper[1]) {
+      prior = dpois(modeldim - 1, hyper[0], 0);
+    }
+  return(prior);
+}
+
